==> haskell-aws-0.24.1-72-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24.1
visibility:           public
id:                   aws-0.24.1-17JeRlhYNAT6j4vWmf4XFR
key:                  aws-0.24.1-17JeRlhYNAT6j4vWmf4XFR
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  08efdea607528adbed9567941384fb11
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24.1-17JeRlhYNAT6j4vWmf4XFR
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    base16-bytestring-1.0.2.0-ASFphLrgXvi67bm2qxzorY
    base64-bytestring-1.2.1.0-Fa0BuK0N9mu9JPJP7gaxRT
    blaze-builder-0.4.4-1ntb6RP4OewIlLWEkSeIAR
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-extra-1.3.8-CgVZWFLveL3JOQpGK40p1j containers-0.6.7
    cryptonite-0.30-J05HlVSc5IIHLQ8uVby8as
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
    http-conduit-2.3.9.1-Ez7Wwb3oy5J4EzeufIRGd5
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    lifted-base-0.2.3.12-HR3njwBKkQfIczM7PCgcTP
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-control-1.0.3.1-GptxzQqshh7J2Y4ewMk2Hl mtl-2.2.2
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    network-bsd-2.8.1.0-FFpbVO9AuzE8JLFVOXvOKf
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP
    safe-0.3.21-FBimV6u2RMNDKpiH5qP0vN
    scientific-0.3.8.0-L88GQ4rEhQfGc3NVSCAVTu
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57
    xml-conduit-1.9.1.4-4j2T32Yc9L746h6qu9IdEP

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.24.1-101-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24.1
visibility:           public
id:                   aws-0.24.1-Ayq1LztsOLGFeTuBkkFN5W
key:                  aws-0.24.1-Ayq1LztsOLGFeTuBkkFN5W
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  a6eac819a743d48012c413efe99187d0
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24.1-Ayq1LztsOLGFeTuBkkFN5W
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    base16-bytestring-1.0.2.0-1Uz6oHjhPf9KewF5fWee2u
    base64-bytestring-1.2.1.0-G8BjkxE58WI1uqeVjCB0n4
    blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-extra-1.3.8-1hrV1nPRDhE45dAx9zvo6P containers-0.6.7
    cryptonite-0.30-5T9hA5iejCiIzteqbNsY1m
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    http-conduit-2.3.9.1-Jt8i9zz8puP9BUVEul6uLX
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    lifted-base-0.2.3.12-BlE7lcjJgycKqbOSX0EJAx
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs mtl-2.2.2
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    network-bsd-2.8.1.0-45NgNz6r2kWHrH0TdvR5cZ
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl
    safe-0.3.21-JMKA2bKqr97GM6r3OADsOi
    scientific-0.3.8.0-6QoqQGQc0yZ1FsULZsdy9C
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    xml-conduit-1.9.1.4-93p77c2FG7W9C5BkdNl9oF

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
